@@ -1,8 +1,5 @@
 package Pod::PseudoPod::LaTeX;
-BEGIN {
-  $Pod::PseudoPod::LaTeX::VERSION = '1.20110710';
-}
-
+$Pod::PseudoPod::LaTeX::VERSION = '1.20160626';
 use Pod::PseudoPod 0.16;
 
 use base 'Pod::PseudoPod';
@@ -18,7 +15,9 @@ sub new
     my ( $class, %args ) = @_;
     my $self             = $class->SUPER::new(%args);
 
-    $self->{keep_ligatures} = exists($args{keep_ligatures}) ? $args{keep_ligatures} : 0;
+    $self->{keep_ligatures}  = exists($args{keep_ligatures})  ? $args{keep_ligatures}  : 0;
+    $self->{captions_below} = exists($args{captions_below}) ? $args{captions_below} : 0;
+    $self->{full}           = exists($args{full})           ? $args{full}           : 0;
 
     # These have their contents parsed
     $self->accept_targets_as_text(
@@ -45,9 +44,24 @@ sub emit_environments
     }
 }
 
+sub start_Document
+{
+    my $self = shift;
+    if ($self->{full}) {
+        $self->{scratch} .= "\\documentclass[12pt,a4paper]{book}\n"
+                         .  "\\usepackage{fancyvrb}\n"
+                         .  "\\usepackage{url}\n"
+                         .  "\\usepackage{titleref}\n"
+                         .  "\\usepackage[T1]{fontenc}\n"
+                         .  "\\usepackage{textcomp}\n"
+                         .  "\\begin{document}\n";
+    }
+}
+
 sub end_Document
 {
     my $self = shift;
+    $self->{scratch} .= "\\end{document}\n" if $self->{full};
     $self->emit();
 }
 
@@ -180,11 +194,11 @@ my %characters = (
     acute   => sub { qq|\\'| . shift },
     grave   => sub { qq|\\`| . shift },
     uml     => sub { qq|\\"| . shift },
-    cedilla => sub { '\c' },              # ccedilla
-    opy     => sub { '\copyright' },      # copy
-    dash    => sub { '---' },             # mdash
-    lusmn   => sub { '\pm' },             # plusmn
-    mp      => sub { '\&' },              # amp
+    cedilla => sub { '\c{c}' },              # ccedilla
+    opy     => sub { '\copyright' },         # copy
+    dash    => sub { '---' },                # mdash
+    lusmn   => sub { '\ensuremath{\pm}' },   # plusmn
+    mp      => sub { '\&' },                 # amp
 );
 
 sub end_E
@@ -417,11 +431,16 @@ sub start_figure
 
     $self->{scratch} .= "\\begin{figure}[!h]\n";
 
-    if ( $flags->{title} )
-    {
-        my $title = $self->encode_text( $flags->{title} );
-        $title    =~ s/^graphic\s*//;
-        $self->{scratch} .= "\\caption{" . $title . "}\n";
+    $self->{_dangling_title} = undef; # just in case; Do not think it is worth a stack.
+    if ( $flags->{title} ) {
+        if ($self->{captions_below}) {
+            $self->{_dangling_title} = $flags->{title};
+        }
+        else {
+            my $title = $self->encode_text( $flags->{title} );
+            $title    =~ s/^graphic\s*//;
+            $self->{scratch} .= "\\caption{" . $title . "}\n";
+        }
     }
 
     $self->{scratch} .= "\\begin{center}\n";
@@ -432,6 +451,15 @@ sub end_figure
 {
     my $self = shift;
     $self->{scratch} .= "\\end{center}\n";
+
+    if ($self->{captions_below} && $self->{_dangling_title})
+    {
+        my $title = $self->encode_text( $self->{_dangling_title} );
+        $title    =~ s/^graphic\s*//;
+        $self->{scratch} .= "\\caption{" . $title . "}\n";
+        $self->{_dangling_title} = undef; # clear it
+    }
+
     $self->{scratch} .= "\\end{figure}\n";
     $self->{flags}{in_figure}--;
     $self->emit();
@@ -444,11 +472,17 @@ sub start_table
     # Open the table
     $self->{scratch} .= "\\begin{table}[!h]\n";
 
+    $self->{_dangling_title} = undef; # just in case; Do not think it is worth a stack.
     if ( $flags->{title} )
     {
-        my $title = $self->encode_text( $flags->{title} );
-        $title    =~ s/^graphic\s*//;
-        $self->{scratch} .= "\\caption{" . $title . "}\n";
+        if ($self->{captions_below}) {
+            $self->{_dangling_title} = $flags->{title};
+        }
+        else {
+            my $title = $self->encode_text( $flags->{title} );
+            $title    =~ s/^graphic\s*//;
+            $self->{scratch} .= "\\caption{" . $title . "}\n";
+        }
     }
     $self->{scratch} .= "\\begin{center}\n";
 
@@ -479,8 +513,18 @@ sub end_table
 
     # Close the table
     $self->{scratch} .= "\\end{tabular}\n"
-                     .  "\\end{center}\n"
-                     .  "\\end{table}\n";
+                     .  "\\end{center}\n";
+
+
+    if ($self->{captions_below} && $self->{_dangling_title})
+    {
+        my $title = $self->encode_text( $self->{_dangling_title} );
+        $title    =~ s/^graphic\s*//;
+        $self->{scratch} .= "\\caption{" . $title . "}\n";
+        $self->{_dangling_title} = undef; # clear it
+    }
+
+    $self->{scratch}.= "\\end{table}\n";
 
     $self->{flags}{in_table}--;
     delete $self->{table_rows};
@@ -683,13 +727,15 @@ BEGIN
 1;
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 Pod::PseudoPod::LaTeX - convert Pod::PseudoPod documents into LaTeX
 
 =head1 SYNOPSIS
 
-This module is a Pod::PseudoPod subclass, itself a Pod::Simple subclass.  This
+This module is a C<Pod::PseudoPod> subclass, itself a C<Pod::Simple> subclass.  This
 means that this is a full-fledged POD parser.  Anything those modules can do,
 this can do.
 
@@ -698,13 +744,13 @@ Perhaps a little code snippet.
     use Pod::PseudoPod::LaTeX;
 
     my $parser = Pod::PseudoPod::LaTeX->new();
-        $parser->emit_environments( sidebar => 'sidebar' );
+    $parser->emit_environments( sidebar => 'sidebar' );
     $parser->output_fh( $some_fh );
     $parser->parse_file( 'some_document.pod' );
 
     ...
 
-=head1 LATEX PRELUDE
+=head1 LATEX PREAMBLE
 
 The generated LaTeX code needs some packages to be loaded to work correctly.
 Currently it needs
@@ -728,40 +774,50 @@ Currently we support:
 
 =item C<keep_ligatures>
 
-LaTeX usually joins some pair of letters (ff, fi and fl), named
-ligatures. By default the module split thems. If you prefer to render
+LaTeX usually joins some pairs of letters (ff, fi and fl), named
+ligatures. By default the module splits them. If you prefer to render
 them with ligatures, use:
 
-  my $parser = Pod::PseudoPod::LaTeX->new( keep_ligatures => 1 );
+    my $parser = Pod::PseudoPod::LaTeX->new( keep_ligatures => 1 );
+
+=item C<captions_below>
+
+Set this flag to a true value if you prefer that figure and table
+captions are placed below the object and not above (the default).
+
+=item C<full>
+
+Create a standalone document which can immediately be run through C<latex>
+or C<pdflatex>.
 
 =back
 
 =head1 STYLES / EMITTING ENVIRONMENTS
 
 The C<emit_environments> method accepts a hashref whose keys are POD environments
-and values are latex environments. Use this method if you would like
+and values are LaTeX environments. Use this method if you would like
 C<Pod::PseudoPod::LaTeX> to emit a simple C<\begin{foo}...\end{foo}> environment
-rather than emit specific formatting codes. You must define any environemtns you
-use in this way in your latex prelude.
+rather than emit specific formatting codes. You must define any environments you
+use in this way in your LaTeX prelude.
 
 You can define your own environments easily. First you need to define
 the C<=begin...=end> environment with:
 
-  $parser->acept_target_as_text('my_environment');
+    $parser->acept_target_as_text('my_environment');
 
 Then, you can use the C<emit_environments> method to tell
 C<Pod::PseudoPod::LaTeX> what LaTeX environment to emit:
 
-  $parser->emit_environments('my_environment' => 'latex_env');
+    $parser->emit_environments('my_environment' => 'latex_env');
 
 Also, if C<my_environment> is used in POD with a title, it is passed
 as the first argument to the LaTeX environment. That is,
 
-  =begin my_environment Some title
+    =begin my_environment Some title
 
 Will generate
 
-  \begin{latex_env}{Some title}
+    \begin{latex_env}{Some title}
 
 =head1 AUTHOR
 
